pub enum Blocked {
Idle,
Sleeping {
next_wakeup: Instant,
},
Deadlock(Vec<SendBlock>),
Breakpoint(Name, Effect),
Busy {
external_effects: usize,
stages: Vec<Name>,
},
Terminated(Name),
}Expand description
Classification of why SimulationRunning::run_until_blocked has stopped.
Variants
Idle
All stages are suspended on Effect::Receive.
Sleeping
The simulation is waiting for a wakeup with no external effects pending.
Deadlock(Vec<SendBlock>)
All stages are suspended on either Effect::Receive or Effect::Send.
Breakpoint(Name, Effect)
The given breakpoint was hit.
Busy
The given stages are suspended on effects other than Effect::Receive
while none are suspended on Effect::Send. The given number of
external effects are currently unresolved.
Terminated(Name)
The given stage has terminated.
Implementations
Sourceimpl Blocked
impl Blocked
Sourcepub fn assert_idle(&self)
pub fn assert_idle(&self)
Assert that the blocking reason is Idle.
Sourcepub fn assert_sleeping(&self) -> Instant
pub fn assert_sleeping(&self) -> Instant
Assert that the blocking reason is Sleeping.
Sourcepub fn assert_sleeping_until(&self, until: Instant)
pub fn assert_sleeping_until(&self, until: Instant)
Assert that the blocking reason is Sleeping until the given instant.
Sourcepub fn assert_deadlock(
&self,
names: impl IntoIterator<Item = impl AsRef<str> + Debug>,
)
pub fn assert_deadlock( &self, names: impl IntoIterator<Item = impl AsRef<str> + Debug>, )
Assert that the blocking reason is Deadlock by at least the given stages.
Sourcepub fn assert_busy(
&self,
names: impl IntoIterator<Item = impl AsRef<str> + Debug>,
) -> &Self
pub fn assert_busy( &self, names: impl IntoIterator<Item = impl AsRef<str> + Debug>, ) -> &Self
Assert that the blocking reason is Busy by at least the given stages.
pub fn assert_external_effects(&self, effects: usize)
Sourcepub fn assert_breakpoint(self, name: impl AsRef<str>) -> Effect
pub fn assert_breakpoint(self, name: impl AsRef<str>) -> Effect
Assert that the blocking reason is Breakpoint by the given name.
Sourcepub fn assert_terminated(self, name: impl AsRef<str>)
pub fn assert_terminated(self, name: impl AsRef<str>)
Assert that the blocking reason is Terminated by the given name.