pub enum OverrideResult<In, Out> {
NoMatch(In),
Handled(Box<dyn SendData>),
Replaced(Out),
}Expand description
The result of an override.
This is used to determine what to do with an effect that has been passed to an override.
Variants
NoMatch(In)
The effect was not handled and shall be passed to overrides installed later than this one.
Handled(Box<dyn SendData>)
The effect was handled and the message shall be delivered to the stage as the result.
Replaced(Out)
The effect was replaced by this new effect that will be run instead.