pub struct StageStateRef<Msg, St> { /* private fields */ }Expand description
A handle for sending messages to a stage via the Effects argument to the stage transition function.
This is a variant that is mostly useful in tests because it allows extracting the current state of the stage.
Implementations
Sourceimpl<Msg, St> StageStateRef<Msg, St>
impl<Msg, St> StageStateRef<Msg, St>
pub fn without_state(self) -> StageRef<Msg>