pub struct Instant(/* private fields */);Expand description
A point in time in the simulation.
Note that this is an opaque type that serialises and prints as a duration since the EPOCH.
Implementations
Sourceimpl Instant
impl Instant
pub fn with_tolerance_for_test( tolerance: Duration, ) -> DropGuard<Duration, fn(Duration)>
pub fn pretty(self, now: Self) -> String
pub fn saturating_since(&self, other: Self) -> Duration
pub fn checked_since(&self, other: Self) -> Option<Duration>
pub fn at_offset(offset: Duration) -> Self