OutputEffect

Struct OutputEffect 

pub struct OutputEffect<Msg> {
    pub name: Name,
    pub msg: Msg,
    /* private fields */
}
An effect that sends a message to an output channel.

This is used to send messages to the output stage, which is used to collect the results of the simulation.

The OutputEffect is created by StageGraph::output.

Fields

name: Namemsg: Msg

Implementations

Source

impl<Msg> OutputEffect<Msg>

pub fn new(name: Name, msg: Msg, sender: Sender<Msg>) -> Self

pub fn fake(name: Name, msg: Msg) -> (Self, Receiver<Msg>)

Create a fake output effect for testing.