pub struct ScheduleId(/* private fields */);Expand description
A time specifying when an effect should be executed. The identifier (u64) specifies the precise effect to execute at that time in a map of scheduled effects maintained by the runtime (whether simulation or tokio).
It is important to note that ScheduleId is ordered by time first, then by id.
Implementations