pub enum TraceEntry {
Suspend(Effect),
Resume {
stage: Name,
response: StageResponse,
},
Clock(Instant),
Input {
stage: Name,
input: Box<dyn SendData>,
},
State {
stage: Name,
state: Box<dyn SendData>,
},
Terminated {
stage: Name,
reason: TerminationReason,
},
}Expand description
An owned entry can be serialized and deserialized.
However, we need the entries in the continuation of the running program and we cannot clone,
so there is a variant of this enum with the very same structure the captures only references
to work around this problem: TraceEntryRef.
Variants
Implementations
Sourceimpl TraceEntry
impl TraceEntry
Sourcepub fn resume(stage: impl AsRef<str>, response: StageResponse) -> Self
pub fn resume(stage: impl AsRef<str>, response: StageResponse) -> Self
Construct a resume entry.
Sourcepub fn input(stage: impl AsRef<str>, input: Box<dyn SendData>) -> Self
pub fn input(stage: impl AsRef<str>, input: Box<dyn SendData>) -> Self
Construct an input entry.
Sourcepub fn state(stage: impl AsRef<str>, state: Box<dyn SendData>) -> Self
pub fn state(stage: impl AsRef<str>, state: Box<dyn SendData>) -> Self
Construct a state entry.
Sourcepub fn terminated(stage: impl AsRef<str>, reason: TerminationReason) -> Self
pub fn terminated(stage: impl AsRef<str>, reason: TerminationReason) -> Self
Construct a terminated entry.
pub fn at_stage<'a, 'b: 'a>(&'b self) -> Option<&'a Name>