StageGraphRunning

Trait StageGraphRunning 

pub trait StageGraphRunning {
    // Required methods
    fn is_terminated(&self) -> bool;
    fn termination(&self) -> BoxFuture<'static, ()>;
}
A trait for running stage graphs.

This trait is implemented by the return value of the SimulationBuilder::run method.

Required Methods

fn is_terminated(&self) -> bool

Returns true if the stage graph has observed a termination signal.

fn termination(&self) -> BoxFuture<'static, ()>

A future that resolves once the stage graph has terminated.

Implementors