pub struct OutputEffect<Msg> {
pub name: Name,
pub msg: Msg,
/* private fields */
}Expand description
An effect that sends a message to an output channel.
This is used to send messages to the output stage, which is used to collect the results of the simulation.
The OutputEffect is created by StageGraph::output.
Fields
name: Namemsg: MsgImplementations