pub trait ExternalEffectAPI: ExternalEffect {
type Response: SendData + DeserializeOwned;
}Expand description
Separate trait for fixing the response type of an external effect.
This cannot be included in ExternalEffect because it would require a type parameter, which
in turn would make that trait non-object-safe.
Required Associated Types
type Response: SendData + DeserializeOwned
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".