ExternalEffectAPI

Trait ExternalEffectAPI 

pub trait ExternalEffectAPI: ExternalEffect {
    type Response: SendData + DeserializeOwned;
}
Separate trait for fixing the response type of an external effect.

This cannot be included in ExternalEffect because it would require a type parameter, which in turn would make that trait non-object-safe.

Required Associated Types

Implementations on Foreign Types

Source

impl ExternalEffectAPI for ()

Implementors