pub trait ExternalEffectAPI: ExternalEffect {
type Response: SendData + DeserializeOwned;
}Expand description
Separate trait for fixing the response type of an external effect.
This cannot be included in ExternalEffect because it would require a type parameter, which
in turn would make that trait non-object-safe.